@@ -1,4 +1,4 @@
-#Copyright ReportLab Europe Ltd. 2000-2016
+#Copyright ReportLab Europe Ltd. 2000-2017
 #see license.txt for license details
 """
 Tests for chart class.
@@ -24,7 +24,7 @@ from reportlab.platypus.frames import Frame
 from reportlab.platypus.doctemplate import PageTemplate, BaseDocTemplate
 from reportlab.graphics.charts.barcharts import VerticalBarChart
 from reportlab.graphics.charts.linecharts import HorizontalLineChart
-from reportlab.graphics.charts.lineplots import LinePlot
+from reportlab.graphics.charts.lineplots import LinePlot, GridLinePlot
 from reportlab.graphics.charts.piecharts import Pie
 from reportlab.graphics.charts.legends import Legend
 from reportlab.graphics.charts.spider import SpiderChart
@@ -359,6 +359,16 @@ class ChartTestCase(unittest.TestCase):
                 story.append(code(i))
                 story.append(Spacer(0, 1*cm))
 
+    def test4c(self):
+        story = self.story
+        d=Drawing(215,115)
+        d.add(GridLinePlot(),name='chart')
+        d.chart.y = 20
+        story.append(Paragraph('GridLinePlot', h2))
+        story.append(Spacer(0, 0.5*cm))
+        story.append(d)
+        story.append(Spacer(0, 1*cm))
+
     def test5(self):
         "Test pie charts."
 
@@ -476,7 +486,16 @@ class ChartTestCase(unittest.TestCase):
         global FINISHED
         FINISHED = 1
 
-
+    def test801(self):
+        '''test for bitbucket issue 105 reported by Johann Du Toit'''
+        from reportlab.graphics.charts.doughnut import Doughnut
+        from reportlab.graphics import renderSVG
+        d = Drawing(500, 500)
+        pie = Doughnut()
+        pie.data = [5]
+        pie.labels = ['Only 1 Value','']
+        d.add(pie)
+        s = renderSVG.drawToString(d)
 
 def makeSuite():
     return makeSuiteForClasses(ChartTestCase)
